@@ -11,26 +11,24 @@
 <meta name="generator" content="<?cs var:html_escape(VERSION ESCAPE) ?>" />
 <link media="all" href="<?cs var:StaticURI ?>/tdiary/base.css?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
 <link media="all" href="<?cs var:StaticURI ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:BBS_TYPE_THEME ?>/<?cs var:BBS_TYPE_THEME ?>.css<?cs else ?>default/default.css<?cs /if ?>?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
-<!--meta.txto͕-->
-<?cs var:META ?>
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
 <script type="text/javascript">
 //<![CDATA[
-$(function () {
-    $("//input[@name='FROM']").val($.cookie("NAME"));
-    $("//input[@name='mail']").val($.cookie("MAIL"));
-    $("form").submit(function () {
-        if ( !$("textarea[@name='MESSAGE']", this).val() &&
-            $("input[@type='submit']", this).val() == "" ) {
+jQuery(function () {
+    jQuery("//input[@name='FROM']").val(jQuery.cookie("NAME"));
+    jQuery("//input[@name='mail']").val(jQuery.cookie("MAIL"));
+    jQuery("form.comment").submit(function () {
+        if ( !jQuery("textarea[@name='MESSAGE']", this).val() &&
+            jQuery("input[@type='submit']", this).val() == "" ) {
             if ( confirm("{܂Błe܂H") == false ) {
                 return false;
             }
         }
         var option = { "expires": 30, "path": "<?cs var:BBS_COOKIE_PATH ?>" };
-        $.cookie( "NAME", $("//input[@name='FROM']").val(), option );
-        $.cookie( "MAIL", $("//input[@name='mail']").val(), option );
-        $("//input[@type='submit']").attr({ "disabled": true });
+        jQuery.cookie( "NAME", jQuery( "input[@name='FROM']", this ).val(), option );
+        jQuery.cookie( "MAIL", jQuery( "input[@name='mail']", this ).val(), option );
+        jQuery("//input[@type='submit']").attr({ "disabled": true });
         return true;
     });
 });
@@ -50,13 +48,15 @@ img { border: 0px; }
 .center { text-align:center !important;  }
 .clear { clear: both !important; }
 .icon-align { vertical-align: top; }
-.image { border: none; float: left; }
+.image { border: none; float: left; margin-right: 4px; margin-bottom: 1px; }
 .nomail { color: <?cs var:BBS_NAME_COLOR ?> }
 .right { text-align: right !important; }
 .thread_info {}
 .res_body { line-height: 100% !important; }
 /* ]]> */
 </style>
+<!--meta.txto͕-->
+<?cs var:META ?>
 </head>
 <body>
 
@@ -154,7 +154,7 @@ img { border: 0px; }
  </div>
  <?cs /if ?>
  <div class="referer">
-  <a href="<?cs var:ReadCGIURI ?>/l<?cs var:ResCount ?>-">VX̕\</a>
+  <a href="<?cs var:ReadCGIURI ?>/<?cs var:ResCount ?>-n">VX̕\</a>
   <a href="<?cs var:BBSURI ?>/">fɖ߂</a>
   <a href="<?cs var:ReadCGIURI ?>/">S</a>
   <a href="<?cs var:ReadCGIURI ?>/<?cs var:PrevStart ?>-<?cs var:PrevEnd ?>">O100</a>
