@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Read.pm 60 2006-12-31 00:29:40Z hikarin $
+# $Id: Read.pm 96 2007-01-16 13:47:54Z hikarin $
 #
 
 package Img0ch::App::Read;
@@ -92,6 +92,9 @@ sub init {
     my $iConfig  = $iApp->{_config};
     my $iRequest = $iApp->{_request};
     my $mobile   = $option->{mobile};
+
+    $iConfig->get('Maintenance')
+        and die 'img0ch MAINTENANCE: Please try again later.', "\n";
     $iRequest->init($iConfig);
     $iApp->_parse_from_request( $iConfig, $iRequest, $mobile );
 
@@ -334,8 +337,9 @@ sub _parse_from_request {
         else {
             $raw = $path[3] || ( $mobile ? $path[2] : '' );
         }
+
         $iApp->{_param_raw} = $raw;
-        $raw =~ s/[acCi]+\z//xms;
+        $raw =~ s/([acCi]+)\z//xms;
         ( $path[1] || '' ) =~ /([\w\-]+)/xms;
         $iApp->{_param_bbs} = $1;
         '0000000000' =~ /\A(\d+)\z/xms;
@@ -373,15 +377,23 @@ sub _parse_from_request {
 
         my $temp_range_hash = {};
         if ( index( $raw, ',' ) >= 0 ) {
+            my ( $param_recent, $param_nofirst );
             for my $param ( split ',', $raw ) {
                 $param or next;
-                my ( $read_from, $read_to ) = @{ $main_parser->($param) };
+                my ( $read_from, $read_to, $read_recent, $read_nofirst )
+                    = @{ $main_parser->($param) };
+                $read_to ||= $max_read;
                 $swap->( \$read_from, \$read_to );
                 map { $temp_range_hash->{$_} = 1 } (
                     ( $read_from .. $read_to ),
                     @{ $plus_separated_parser->($param) }
                 );
+                $param_recent  ||= $read_recent;
+                $param_nofirst ||= $read_nofirst;
             }
+            #warn scalar keys %$temp_range_hash, "\n";
+            $iApp->{_param_ls} = $param_recent;
+            $iApp->{_param_nofirst} = $param_nofirst;
         }
         else {
             my @range = @{ $plus_separated_parser->($raw) };
@@ -392,7 +404,7 @@ sub _parse_from_request {
                 $read_to ||= $max_read;
                 $iApp->{_param_single}
                     = ( $read_from == $read_to and !$read_recent ) ? 1 : 0;
-                $iApp->{_param_nofirst} = $read_nofirst ? 1 : 0;
+                $iApp->{_param_nofirst} = $read_nofirst;
                 $read_from > $max_read and $read_from = $max_read;
                 $read_to > $max_read   and $read_to   = $max_read;
                 $swap->( \$read_from, \$read_to );
@@ -433,6 +445,7 @@ sub _normalize {
     my $temp_range     = $iApp->{__range_read};
     my $raw            = $iApp->{_param_raw};
     my $last           = $iApp->{_param_ls};
+    my $nofirst        = $iApp->{_param_nofirst};
     my $res_count      = $iApp->{__thread_count};
     my $temp_read_from = $temp_range->[0] || 1;
     my $temp_read_to   = $temp_range->[-1] || $temp_read_from;
@@ -441,46 +454,50 @@ sub _normalize {
     );
 
     if ($is_mobile) {
-        $iApp->{_param_nofirst} = 1;
         $read_by_const--;
-        $raw =~ /i[acCi]*$/xms and $last = 1;
+        if ( $raw =~ /i[acCi]*\z/xms ) {
+            $last = 1;
+            # $temp_read_to = 1001 ( ResMAX )
+            #     =>
+            # $temp_read_to = 10 ( $read_by_const )
+            $temp_read_to = $read_by_const;
+            $nofirst = $iApp->{_param_nofirst} = 0;
+        }
+        else {
+            $nofirst = $iApp->{_param_nofirst} = 1;
+        }
     }
+
     if ($last) {
         my $first = $res_count - $temp_read_to;
         $real_read_from = $first > 0 ? $first : 1;
         ( !$is_mobile ) and $read_by_const = $temp_read_to;
         my $read_to = $real_read_from + $read_by_const;
         $real_read_to = $res_count > $read_to ? $read_to : $res_count;
-        @{$temp_range} = ( $real_read_from .. $real_read_to );
+        @{$temp_range} = $real_read_from .. $real_read_to;
+        if (!$nofirst) {
+            $real_read_from = 1;
+            $temp_range->[0] != 1 and unshift @{$temp_range}, 1;
+        }
     }
     else {
-        if ( $temp_read_to == -1 ) {
-            if ( $is_mobile and $raw =~ /\An/xms ) {
-                $real_read_from = $res_count - $read_by_const;
-                ( $real_read_from < 1 ) and $real_read_from = 1;
-            }
-            elsif ( $temp_read_from > 0 ) {
-                $real_read_from = $temp_read_from;
-            }
-            else {
-                $real_read_from = 1;
-            }
-            my $read_to = $real_read_from + $read_by_const;
-            $real_read_to = $res_count > $read_to ? $read_to : $res_count;
+        if ($nofirst) {
+            $real_read_from = $temp_read_from > 0 ? $temp_read_from : 1;
         }
         else {
-            $real_read_from = $temp_read_from > 0 ? $temp_read_from : 1;
-            $real_read_to =
-                ( $temp_read_to < $res_count ) ? $temp_read_to
-                : (
-                ( $is_mobile and $temp_read_from != $temp_read_to )
-                ? $real_read_from + $read_by_const
-                : $res_count
-                );
+            $real_read_from = 1;
+            $temp_range->[0] != 1 and unshift @{$temp_range}, 1;
         }
+        $real_read_to =
+            ( $temp_read_to < $res_count ) ? $temp_read_to
+            : (
+            ( $is_mobile and $temp_read_from != $temp_read_to )
+            ? $real_read_from + $read_by_const
+            : $res_count
+            );
     }
-    ( $is_mobile and $real_read_to - $real_read_from > $read_by_const )
-        and $real_read_from = $real_read_to - $read_by_const;
+#    ( $is_mobile and $real_read_to - $real_read_from > $read_by_const )
+#        and $real_read_from = $real_read_to - $read_by_const;
 
     my $real_range = [];
     foreach my $i ( @{$temp_range} ) {
