@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Install.pm 60 2006-12-31 00:29:40Z hikarin $
+# $Id: Install.pm 117 2007-01-21 14:55:55Z hikarin $
 #
 
 package Img0ch::Plugin::Install;
@@ -24,6 +24,25 @@ use strict;
 sub install {
     my ($zPlugin) = @_;
 
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::BBS::Coloring',
+            methods => {
+                name => 'bbs.write.pre',
+            },
+        }
+    );
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::BBS::HTMLTag',
+            methods => {
+                parse => 'bbs.write.pre',
+            },
+        }
+    );
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::BBS::RSS',
+            methods => { generate_ver_10 => 'bbs.write.post', },
+        }
+    );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::BBS::UTF8Dat',
             methods => {
@@ -33,8 +52,10 @@ sub install {
         }
     );
     $zPlugin->install(
-        {   package => 'Img0ch::Plugin::BBS::RSS',
-            methods => { generate_ver_10 => 'bbs.write.post', },
+        {   package => 'Img0ch::Plugin::BBS::VIP',
+            methods => {
+                rewrite => 'bbs.write.pre',
+            },
         }
     );
     $zPlugin->install(
@@ -48,6 +69,12 @@ sub install {
                 check_by_bbq  => 'bbs.filter',
                 check_by_bbx  => 'bbs.filter',
                 check_by_dsbl => 'bbs.filter',
+                by_rbl => 'bbs.filter',
+                by_spamcop => 'bbs.filter',
+                by_spamhaus => 'bbs.filter',
+                by_blitzed => 'bbs.filter',
+                by_empty => 'bbs.filter',
+                by_spamlookup => 'bbs.filter',
             },
         }
     );
@@ -56,6 +83,11 @@ sub install {
             methods => { check => 'bbs.filter', },
         }
     );
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::Filter::JPOnly',
+            methods => { check => 'bbs.filter', },
+        }
+    );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Filter::NGWord',
             methods => { check => 'bbs.filter', },
@@ -136,6 +168,21 @@ sub install {
             },
         }
     );
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::Upload::Expires',
+            methods => {
+                at_post_upload => 'bbs.upload.post',
+                at_post_write => 'bbs.wrie.post',
+            },
+        }
+    );
+#    $zPlugin->install(
+#        {   package => 'Img0ch::Plugin::Upload::Note',
+#            methods => {
+#                save => 'bbs.upload.post',
+#            },
+#        }
+#    );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Upload::Thumbnail',
             methods => {
@@ -143,20 +190,6 @@ sub install {
             },
         }
     );
-    $zPlugin->install(
-        {   package => 'Img0ch::Plugin::BBS::HTMLTag',
-            methods => {
-                parse => 'bbs.write.pre',
-            },
-        }
-    );
-    $zPlugin->install(
-        {   package => 'Img0ch::Plugin::BBS::Coloring',
-            methods => {
-                name => 'bbs.write.pre',
-            },
-        }
-    );
 #    $zPlugin->install(
 #        {   package => 'Img0ch::Plugin::Upload::Remove',
 #            methods => {
